@@ -7,9 +7,9 @@ use warnings;
 use parent 'TableData::Munge::Concat';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-18'; # DATE
+our $DATE = '2023-11-25'; # DATE
 our $DIST = 'TableDataBundle-Perl-CPAN-Release'; # DIST
-our $VERSION = '20220218.0'; # VERSION
+our $VERSION = '20231120.2'; # VERSION
 
 sub new {
     my $self = shift;
@@ -20,7 +20,7 @@ sub new {
     $self->SUPER::new(tabledatalist => \@tabledatalist);
 }
 
-our %STATS = ("num_columns",9,"num_rows",354015); # STATS
+our %STATS = ("num_rows",362347,"num_columns",9); # STATS
 
 1;
 # ABSTRACT: CPAN releases (from newest to oldest)
@@ -37,7 +37,7 @@ TableData::Perl::CPAN::Release::Static::FromNewest - CPAN releases (from newest
 
 =head1 VERSION
 
-This document describes version 20220218.0 of TableData::Perl::CPAN::Release::Static::FromNewest (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2022-02-18.
+This document describes version 20231120.2 of TableData::Perl::CPAN::Release::Static::FromNewest (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-11-25.
 
 =head1 SYNOPSIS
 
@@ -69,6 +69,17 @@ To use from command-line (using L<tabledata> CLI):
 
 See the L<tabledata> CLI's documentation for other available actions and options.
 
+=head1 TABLEDATA STATISTICS
+
+ +-------------+--------+
+ | key         | value  |
+ +-------------+--------+
+ | num_columns | 9      |
+ | num_rows    | 362347 |
+ +-------------+--------+
+
+The statistics is available in the C<%STATS> package variable.
+
 =for Pod::Coverage ^(.+)$
 
 =head1 TABLEDATA NOTES
@@ -103,13 +114,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
